ChangeLog — Bloxone API Wrapper 0.1.2 documentation

# ChangeLog

20200714 v0.3.0 Added specific add/delete tags for on_prem_hosts
20200714 v0.2.4 Added create and update methods to b1platform class
20200713 v0.2.1 Renamed patch to update as originally intended
20200713 v0.2.0 Removed original methods for get_object
20200713 v0.1.5 Added get_object_by_key and create initial documentation
20200711 v0.1.2 Added generic wrappers for DDI for create and delete
Added get_id method to get object id from key/value pair
20200710 v0.1.1 Generic Wrapper and restructuring
20200708 v0.0.5 Read only examples for several b1 objects
Commit before restructuring to a more generic
wrappers and useful functions
20200701 v0.0.2 Subclass for b1ddi api methods added to b1
20200629 v0.0.1 Initial Class commit for b1 class
Base class attributes and ini file
handling.